# API Reference

This page provides an auto-generated summary of intake-esm’s API.
For more details and examples, refer to the relevant chapters in the main part of the documentation.

## ESM Datastore (`intake.open_esm_datastore`)

```{eval-rst}
.. automodule:: intake_esm.core
    :members:
```
